package com.bio.bio_backend.domain.user.member.service;

import java.util.List;
import java.util.Map;

import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;

import com.bio.bio_backend.domain.user.member.dto.MemberDto;

public interface MemberService extends UserDetailsService {

    UserDetails loadUserByUsername(String id);

    MemberDto createMember(MemberDto memberDTO);

    void updateRefreshToken(MemberDto memberDTO);

    String getRefreshToken(String id);

    int deleteRefreshToken(String id);

    List<MemberDto> selectMemberList(Map<String, String> params);

    MemberDto selectMember(long seq);

    int updateMember(MemberDto member);

    int deleteMember(MemberDto member);
}
